@@ -8,7 +8,7 @@ sub tables {
     my $self = shift;
     my $quoter = $self->quoter;
     my $namesep = $self->namesep;
-    my @tables = $self->{ dbh }->tables(undef, undef, '', '');
+    my @tables = $self->{ dbh }->tables(undef, undef, '', 'TABLE');
     s/\Q$quoter\E//g for @tables;
     s/^.*\Q$namesep\E// for @tables;
     return \@tables;
