@@ -1,6 +1,6 @@
 package Mock::DB;
 
-use DBIx::Skinny setup => +{
+use DBIx::Skinny connect_info => +{
     dsn => 'dbi:SQLite:test.db',
     username => '',
     password => '',
